import { select,line, scaleLinear,
max,csv,extent,scaleBand, axisBottom,
axisLeft,scaleTime,schemeCategory10} from 'd3';

import {colorLegend} from './colorLegend'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render= data=>{

const margin = { top: 30, right: 20, bottom: 20, left: 50 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const xValue = d=>d.timestamp;
const yValue =  d=>d.temperature;

const colorValue = d=>d.city;

// now for the scales
const xscale = scaleTime()
.domain(extent(data,xValue))
.range([0, innerWidth])
.nice();

const colorScale = d3.scaleOrdinal(d3.schemeCategory10);

const yscale = scaleLinear()
.domain(extent(data, yValue))
.range([innerHeight, 0])
.nice();
  
console.log(xscale.domain())  
  
// now for the axis

const g = svg.append("g")
.attr("transform", `translate(${margin.left},${margin.top})`);

  
const xAxis = axisBottom(xscale)
.tickSize(-innerHeight)
    
const yAxis = axisLeft(yscale)
.tickSize(-innerWidth);

const xAxisG = g.append("g")
.call(xAxis)
.attr("transform", `translate(0,${innerHeight})`);

const yAxisG = g.append("g").call(yAxis);
  
//now for the line
const lineGenerator = line()
.x(d => xscale(xValue(d)))
.y(d => yscale(yValue(d)))
.curve(d3.curveBasis)

const nested = d3.nest()
.key(colorValue)
.entries(data);

colorScale.domain(nested.map(function(d) {
return d.key;})
);

console.log(nested)  
g.selectAll('.line-path')
.data(nested)
.enter().append('path')  
.attr('class','line-path')
.attr('fill','none')  
.attr('d', d=>lineGenerator(d.values))  
.attr('stroke',function(d){return colorScale(d.key)})  

svg.append('g')
.attr('transform', `translate(665,65)`)
.call(colorLegend, {
colorScale,
circleRadius: 15,
spacing: 65,
textOffset: 40
});

};

csv('https://vizhub.com/curran/datasets/data-canvas-sense-your-city-one-week.csv')
.then(function(data){
data.forEach(function(d){
d.temperature=+d.temperature;
d.timestamp= new Date(d.timestamp)  
})  
console.log(data)
render(data) 
})

